@@ -10,7 +10,7 @@ def pose_infer_demo():
     img = 'pose2.jpg' # 指定进行推理的图片路径
     img = cv2.imread(img)
 
-    det = wf(task='det_body_l')#,checkpoint="checkpoints/bodydetect_l.onnx")
+    det = wf(task='det_body_L')#,checkpoint="checkpoints/bodydetect_l.onnx")
     pose = wf(task='pose_body_l')# ,checkpoint="rtmpose-l-19c9d1.onnx")# "rtmpose-m-80e511.onnx") # 实例化mmpose模型
     
     import time
@@ -81,7 +81,7 @@ def hand_video_demo():
     cv2.destroyAllWindows()
 
 def coco_det_demo():
-    img = 'coco.jpg' # 指定进行推理的图片路径
+    img = 'cat.jpg' # 指定进行推理的图片路径
     det = wf(task='det_coco_l')#,checkpoint="checkpoints/cocodetect_l.onnx") # 实例化mmpose模型
 
     result,img = det.inference(data=img,img_type='pil',thr=0.3) # 在CPU上进行推理
@@ -109,7 +109,7 @@ def face_det_demo():
 
 def ocr_demo():
     img = 'ocr.jpg' # 指定进行推理的图片路径
-    ocr = wf(task='ocr' )#,checkpoint="rtmdet-coco.onnx") # 实例化mmpose模型
+    ocr = wf(task='ocr' ,download_path='ocr_file')#,checkpoint="rtmdet-coco.onnx") # 实例化mmpose模型
 
     result,img = ocr.inference(data=img,img_type='pil',show=True) # 在CPU上进行推理
     # print(result)
@@ -204,27 +204,12 @@ def sup_demo():
     cos_sim = vec1.dot(vec2) / (np.linalg.norm(vec1) * np.linalg.norm(vec2))
     print(cos_sim)
 
-def style():
+def style_demo():
     for i in range(5):
-        style = wf(task='gen_style' ,style=i) # iris act 
+        style = wf(task='gen_style' ,style='mosaic') # iris act 
         result = style.inference(data="ele.jpg" ,img_type='cv2')
         style.show(result)
         style.save(result,"ele_{}.jpg".format(i))
-    #     result,img = style.inference(data="ele.jpg" ,img_type='cv2')
-    #     style.show(result)
-    #     result,img = style.inference(data="ele.jpg" ,img_type='pil')
-    #     style.show(result)
-    #     result = style.inference(data="ele.jpg" ,img_type='pil')
-    #     style.show(result)
-        # style.format_output(lang="zh")
-        # cv2.imshow("img",img)
-        # cv2.imshow("result",result)
-        # cv2.waitKey(0)
-        # style.show(img)
-    # styles = [ wf(task='gen_style',style=i) for i in range(5) ]
-    # # result,img = style.inference(data="ele.jpg",img_type='pil')
-    # import random
-    # # style.show(result)
     # # 打开摄像头，实时风格迁移
     # cap = cv2.VideoCapture(0)
     # while cap.isOpened():
@@ -272,15 +257,32 @@ def sim():
 
 def drive_demo():
     from XEdu.hub import Workflow as wf
-    drp = wf(task='drive_perception')# ,checkpoint="checkpoints/yolopv2_post_Nx3x192x320.onnx") 
+    drp = wf(task='drive_perception')
     # result = drp.inference(data="demo.jpg")
 
     result,image = drp.inference(data="cat1.jpg",img_type='pil')
-    drp.format_output(lang="zh")
+    drp.format_output(lang="zh",isprint=False)
 
     drp.show(image)
     # drp.save(image,"demo_ou.jpg")
 
+def embedding_demo():
+    from XEdu.hub import Workflow as wf
+    from XEdu.utils import get_similarity
+    img_emb = wf(task='embedding_image')
+    text_emb = wf(task='embedding_text')
+    images = ["cat.jpg"]
+    texts_zh = ["猫", "狗"]
+    texts_en = ["cat", "dog"]
+
+    image_embeddings = img_emb.inference(data=images)
+    text_zh_embeddings = text_emb.inference(data=texts_zh)
+    text_en_embeddings = text_emb.inference(data=texts_en)
+
+    # logits = get_similarity(image_embeddings,text_zh_embeddings,method='cosine',use_softmax=False)
+    logits = get_similarity(text_en_embeddings,text_zh_embeddings) # ,method='cosine',use_softmax=False)
+    print("cosine", logits)
+
 if __name__ == "__main__":
     pose_infer_demo()
     # det_infer_demo()
@@ -295,7 +297,7 @@ if __name__ == "__main__":
     # basenn_demo()
     # cls_demo()
     # baseml_demo()
-    # style()
+    # style_demo()
     # qa_demo()
     # drive_demo()
-
+    # embedding_demo()
\ No newline at end of file
